<?xml version = '1.0'?>
<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui version="40" name="tellico">
 <MenuBar>
  <Menu name="file">
   <text>&amp;File</text>
   <Menu append="new_merge" name="file_new_collection" >
    <text>&amp;New Collection</text>
    <Action name="new_book_collection"/>
    <Action name="new_bibtex_collection"/>
    <Action name="new_comic_book_collection"/>
    <Action name="new_video_collection"/>
    <Action name="new_music_collection"/>
    <Action name="new_coin_collection"/>
    <Action name="new_stamp_collection"/>
    <Action name="new_card_collection"/>
    <Action name="new_wine_collection"/>
    <Action name="new_game_collection"/>
    <Action name="new_boardgame_collection"/>
    <Action name="new_file_catalog"/>
    <Action name="new_custom_collection"/>
   </Menu>
   <Menu name="file_import">
    <text context="@title:menu">&amp;Import</text>
    <Action name="file_import_tellico"/>
    <Action name="file_import_csv"/>
    <Action name="file_import_gcstar"/>
    <Action name="file_import_delicious"/>
    <Action name="file_import_collectorz"/>
    <Separator/>
    <Action name="file_import_alexandria"/>
    <Action name="file_import_bibtex"/>
    <Action name="file_import_bibtexml"/>
    <Action name="file_import_mods"/>
    <Action name="file_import_pdf"/>
    <Action name="file_import_referencer"/>
    <Action name="file_import_ris"/>
    <Action name="file_import_goodreads"/>
    <Action name="file_import_librarything"/>
    <Separator/>
    <Action name="file_import_freedb"/>
    <Action name="file_import_audiofile"/>
    <Separator/>
    <Action name="file_import_amc"/>
    <Action name="file_import_griffith"/>
    <Separator/>
    <Action name="file_import_boardgamegeek"/>
    <Separator/>
    <Action name="file_import_vinoxml"/>
    <Separator/>
    <Action name="file_import_filelisting"/>
    <Separator/>
    <Action name="file_import_xslt"/>
   </Menu>
   <Menu name="file_export">
    <text context="@title:menu">&amp;Export</text>
    <Action name="file_export_xml"/>
    <Action name="file_export_zip"/>
    <Action name="file_export_html"/>
    <Action name="file_export_csv"/>
    <Separator/>
    <Action name="file_export_alexandria"/>
    <Action name="file_export_bibtex"/>
    <Action name="file_export_bibtexml"/>
    <Action name="file_export_onix"/>
    <Separator/>
    <Action name="file_export_gcstar"/>
    <Separator/>
    <Action name="file_export_xslt"/>
   </Menu>
  </Menu>
  <Menu name="edit">
   <Action name="filter_dialog"/>
  </Menu>
  <Menu name="collection">
   <text context="@title:menu">&amp;Collection</text>
   <Action name="coll_add_entry"/>
   <Action name="coll_edit_entry"/>
   <Action name="coll_copy_entry"/>
   <Action name="coll_delete_entry"/>
   <Action name="coll_merge_entry"/>
   <Menu name="coll_update_entry">
    <text context="@title:menu">&amp;Update Entry</text>
    <Action name="update_entry_all"/>
    <Separator/>
    <ActionList name="update_entry_actions"/>
   </Menu>
   <Separator/>
   <Action name="coll_checkout"/>
   <Action name="coll_checkin"/>
   <Separator/>
   <Action name="coll_rename_collection"/>
   <Action name="coll_fields"/>
   <Action name="coll_reports"/>
   <Separator/>
   <Menu name="coll_bibliography">
    <text context="@title:menu">&amp;Bibliography</text>
    <Action name="coll_convert_bibliography"/>
    <Action name="coll_string_macros"/>
    <Action name="coll_key_manager"/>
    <Action name="cite_clipboard"/>
    <Action name="cite_lyxpipe"/>
   </Menu>
  </Menu>
  <Menu name="settings">
   <Menu name="dockers" append="show_merge">
     <text context="@title:menu">&amp;Show Views</text>
     <!--<Action name="options_show_statusbar"/>-->
     <Action name="toggle_collection_bar"/>
     <Action name="toggle_group_widget"/>
     <Action name="toggle_column_widget"/>
     <Action name="toggle_edit_widget"/>
   </Menu>
   <Action append="show_merge" name="change_entry_grouping"/>
   <Action append="show_merge" name="lock_layout"/>
   <Action append="show_merge" name="reset_layout"/>
  </Menu>
  <Menu name="help">
   <Action name="tipOfDay"/>
  </Menu>
 </MenuBar>
 <ToolBar noMerge="1" name="mainToolBar">
  <text>Main Toolbar</text>
  <Action name="file_new_collection"/>
  <Action name="file_open"/>
  <Action name="file_save"/>
  <Action name="file_print"/>
 </ToolBar>
 <ToolBar name="collectionToolBar">
  <text>Collection Toolbar</text>
  <Action name="coll_add_entry"/>
  <Action name="coll_fields"/>
  <Action name="coll_reports"/>
  <Action name="change_entry_grouping"/>
  <Separator lineSeparator="true"/>
  <Action name="quick_filter"/>
  <Action name="filter_dialog"/>
 </ToolBar>

<State name="collection_reset">
 <Disable>
  <Action name="file_export_alexandria"/>
  <Action name="file_export_onix"/>
  <Action name="file_export_bibtex"/>
  <Action name="file_export_bibtexml"/>
  <Action name="file_export_gcstar"/>
  <Action name="file_export_amc"/>
  <Action name="coll_convert_bibliography"/>
  <Action name="coll_string_macros"/>
  <Action name="coll_key_manager"/>
  <Action name="cite_clipboard"/>
  <Action name="cite_lyxpipe"/>
 </Disable>
</State>

<State name="is_album">
 <Enable>
  <Action name="file_export_gcstar"/>
 </Enable>
</State>

<State name="is_bibtex">
 <Enable>
  <Action name="file_export_alexandria"/>
  <Action name="file_export_onix"/>
  <Action name="file_export_bibtex"/>
  <Action name="file_export_bibtexml"/>
  <Action name="coll_string_macros"/>
  <Action name="coll_key_manager"/>
 </Enable>
</State>

<State name="is_boardgame">
 <Enable>
  <Action name="file_export_gcstar"/>
 </Enable>
</State>

<State name="is_book">
 <Enable>
  <Action name="file_export_alexandria"/>
  <Action name="file_export_onix"/>
  <Action name="file_export_gcstar"/>
  <Action name="coll_convert_bibliography"/>
 </Enable>
</State>

<State name="is_coin">
 <Enable>
  <Action name="file_export_gcstar"/>
 </Enable>
</State>

<State name="is_comic">
 <Enable>
  <Action name="file_export_gcstar"/>
 </Enable>
</State>

<State name="is_game">
 <Enable>
  <Action name="file_export_gcstar"/>
 </Enable>
</State>

<State name="is_video">
 <Enable>
  <Action name="file_export_amc"/>
  <Action name="file_export_gcstar"/>
 </Enable>
</State>

<State name="is_wine">
 <Enable>
  <Action name="file_export_gcstar"/>
 </Enable>
</State>

<State name="empty_selection">
 <Disable>
  <Action name="coll_edit_entry"/>
  <Action name="coll_copy_entry"/>
  <Action name="coll_delete_entry"/>
  <Action name="coll_update_entry"/>
  <Menu name="coll_update_entry"/>
  <Action name="update_entry_all"/>
  <Action name="coll_checkout"/>
 </Disable>
</State>

</kpartgui>
